@@ -2,9 +2,6 @@ import pytest
 from openfisca_us import CountryTaxBenefitSystem
 from openfisca_core.simulation_builder import SimulationBuilder
 
-system = CountryTaxBenefitSystem()
-builder = SimulationBuilder()
-
 DEFAULT_SITUATION = {
     "people": {"person": {}},
     "tax_units": {"tax_unit": {"members": ["person"]}},
@@ -25,8 +22,12 @@ EXEMPTIONS = (
 )
 
 
+system = CountryTaxBenefitSystem()
+
+simulation = SimulationBuilder().build_from_dict(system, DEFAULT_SITUATION)
+
+
 @pytest.mark.parametrize("variable", system.variables)
 def test_variable(variable: str) -> None:
     if variable not in EXEMPTIONS:
-        simulation = builder.build_from_dict(system, DEFAULT_SITUATION)
         simulation.calculate(variable, 2022)
