@@ -11,7 +11,7 @@ class eitc_phased_in(Variable):
 
     def formula(tax_unit, period, parameters):
         maximum = tax_unit("eitc_maximum", period)
-        phasein_rate = tax_unit("eitc_phasein_rate", period)
+        phase_in_rate = tax_unit("eitc_phase_in_rate", period)
         earned_income = max_(0, tax_unit("filer_earned", period))
-        phased_in_amount = earned_income * phasein_rate
+        phased_in_amount = earned_income * phase_in_rate
         return min_(maximum, phased_in_amount)
